use strict;
use warnings;
package App::Prefix;

our $VERSION = '0.16'; 

# ABSTRACT: provides 'prefix' filter, which prepends data to lines passed
#
# NOTE: main file for this distribution is bin/prefix
# 
#  Copyright 2010-2013 Josh Rabinowitz.
#
# 1;
